@@ -1,12 +1,12 @@
 # Easy.pm - Easy to Use DBI interface
 
 # Copyright (C) 1999,2000,2001,2002 Stefan Hornburg, Dennis Schn
-# Copyright (C) 2003,2004,2005 Stefan Hornburg (Racke) <racke@linuxia.de>
+# Copyright (C) 2003,2004,2005,2006 Stefan Hornburg (Racke) <racke@linuxia.de>
 
 # Authors: Stefan Hornburg (Racke) <racke@linuxia.de>
 #          Dennis Schn <ds@1d10t.de>
 # Maintainer: Stefan Hornburg (Racke) <racke@linuxia.de>
-# Version: 0.16
+# Version: 0.17
 
 # This file is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -38,7 +38,7 @@ require Exporter;
 
 # Public variables
 use vars qw($cache_structs);
-$VERSION = '0.16';
+$VERSION = '0.17';
 $cache_structs = 1;
 
 use DBI;
@@ -1196,8 +1196,11 @@ sub now
 	my $self = shift;
 
     # Postgres and mysql have an special value for the current time
-    return 'now' if $self -> {'DRIVER'} eq 'Pg';
-	return 'now()' if $self -> {'DRIVER'} eq 'mysql';
+	if ($self->{DRIVER} eq 'Pg'
+		|| $self->{DRIVER} eq 'mysql') {
+		return 'now()';
+	}
+	
     # determine current time by yourself
 	scalar (gmtime ());
   }
@@ -1303,6 +1306,9 @@ sub is_auth_error {
 	my ($self, $msg) = @_;
 
 	if ($self->{DRIVER} eq 'mysql') {
+		if ($msg =~ /^DBI\sconnect(\('database=.*?(;host=.*?)?',.*?\))? failed: Access denied for user\s/) {
+			return 1;
+		}
 		if ($msg =~ /^DBI->connect(\(database=.*?(;host=.*?)?\))? failed: Access denied for user:/) {
 			return 1;
 		}
@@ -1372,8 +1378,8 @@ sub passwd {
 sub install_handler {$_[0] -> {'HANDLER'} = $_[1];}
 
 # direct interface to DBI
-sub prepare {$_[0] -> connect () -> prepare (@_);}
-sub commit {$_[0] -> connect () -> commit ();}
+sub prepare {my $self = shift; $self -> connect () -> prepare (@_);}
+sub commit {my $self = shift; $self->connect (); return if $self->{CONN}->{AutoCommit}; $self->{CONN}->commit();}
 sub rollback {$_[0] -> connect () -> rollback ();}
 sub quote {$_[0] -> connect () -> quote ($_[1]);}
 
@@ -1466,14 +1472,14 @@ __END__
 =head1 AUTHORS
 
 Stefan Hornburg (Racke), racke@linuxia.de
-Dennis Schn, ds@1d10t.de
+Dennis Sch\[:o]n, ds@1d10t.de
 
 Support for Sybase and ODBC provided by
 David B. Bitton <david@codenoevil.com>.
 
 =head1 VERSION
 
-0.16
+0.17
 
 =head1 SEE ALSO
 
